%define major              1
%define libname            %mklibname %{name} %{major}
%define libnamedevel       %mklibname %{name} -d
%define libnamestaticdevel %mklibname %{name} -d -s

%define _program_prefix eu-

Summary:	A collection of utilities and DSOs to handle ELF files and DWARF data
Name:		elfutils
Version:	0.189
%define subrel 1
Release:	%mkrel 1
License:	GPLv2+
Group:		Development/Other
Url:		https://sourceware.org/elfutils/
Source0:	https://sourceware.org/elfutils/ftp/%{version}/%{name}-%{version}.tar.bz2
Source1:	https://sourceware.org/elfutils/ftp/%{version}/%{name}-%{version}.tar.bz2.sig

# Mageia patches

# Upstream patches
# https://sourceware.org/git/?p=elfutils.git;a=summary

# Security patches
Patch0:		CVE-2024-25260.patch
Patch1:		CVE-2025-1372.patch
Patch2:		CVE-2025-1377.patch

BuildRequires:	gcc
# For libstdc++ demangle support
BuildRequires:	gcc-c++
BuildRequires:	binutils
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	zstd
BuildRequires:	glibc-devel
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libmicrohttpd)
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	procps
BuildRequires:	lzma-devel
BuildRequires:	gettext-devel
Requires:	%{libname} = %{version}-%{release}

%description
Elfutils is a collection of utilities, including stack (to show
backtraces), nm (for listing symbols from object files), size
(for listing the section sizes of an object or archive file),
strip (for discarding symbols), readelf (to see the raw ELF file
structures), elflint (to check for well-formed ELF files) and
elfcompress (to compress or decompress ELF sections).

%package -n	%{libnamedevel}
Summary:	Development libraries to handle compiled objects
Group:		Development/Other
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	libelf-devel = %{version}-%{release}
Provides:	libelf0-devel = %{version}-%{release}

%description -n	%{libnamedevel}
This package contains the headers and dynamic libraries to create
applications for handling compiled objects.

   * libelf allows you to access the internals of the ELF object file
     format, so you can see the different sections of an ELF file.
   * libebl provides some higher-level ELF access functionality.
   * libasm provides a programmable assembler interface.

%package -n	%{libnamestaticdevel}
Summary:	Static libraries for development with libelfutils
Group:		Development/Other
Requires:	%{libnamedevel} = %{version}-%{release}
Provides:	%{name}-static-devel = %{version}-%{release}
Provides:	libelf-static-devel = %{version}-%{release}
Provides:	libelf0-static-devel = %{version}-%{release}

%description -n	%{libnamestaticdevel}
This package contains the static libraries to create applications for
handling compiled objects.

%package -n	%{libname}
Summary:	Libraries to read and write ELF files
Group:		System/Libraries
Provides:	lib%{name} = %{version}-%{release}
Provides:	libelf = %{version}-%{release}
Provides:	libelf0 = %{version}-%{release}

%description -n	%{libname}
This package provides DSOs which allow reading and writing ELF files
on a high level.  Third party programs depend on this package to read
internals of ELF files.  The programs of the elfutils package use it
also to generate new ELF files.

Also included are numerous helper libraries which implement DWARF,
ELF, and machine-specific ELF handling.

%prep
%setup -q
%autopatch -p1

find . -name \*.sh ! -perm -0100 -print | xargs chmod +x

%build
autoreconf -fiv

# no thread safety please: http://www.mail-archive.com/elfutils-devel@lists.fedorahosted.org/msg01893.html
%configure \
	--host="" \
	%{?_program_prefix: --program-prefix=%{_program_prefix}} \
	--with-zlib \
	--with-bzlib \
	--with-lzma

%make_build

%install
%make_install

chmod +x %{buildroot}%{_libdir}/lib*.so*

# We don't have standard DEBUGINFOD_URLS yet.
rm -f %{buildroot}%{_sysconfdir}/profile.d/debuginfod.sh
rm -f %{buildroot}%{_sysconfdir}/profile.d/debuginfod.csh

%find_lang %{name}

%check
sed -i 's|native_test \${abs_builddir}/funcretval|#native_test \${abs_builddir}/funcretval|' tests/run-native-test.sh
%make_build check || (cat tests/test-suite.log; false)

%files -f %{name}.lang
%doc NOTES README NEWS TODO
%{_bindir}/debuginfod*
%{_bindir}/eu-*

%files -n %{libname}
%license COPYING-GPLV2 COPYING-LGPLV3
%{_libdir}/libdebuginfod-%{version}.so
%{_libdir}/libdebuginfod*.so.%{major}{,.*}
%{_libdir}/libelf-%{version}.so
%{_libdir}/libelf*.so.%{major}{,.*}
%{_libdir}/libasm-%{version}.so
%{_libdir}/libasm.so.*
%{_libdir}/libdw-%{version}.so
%{_libdir}/libdw.so.*
%{_mandir}/*/*

%files -n %{libnamedevel}
%{_includedir}/dwarf.h
%{_includedir}/libelf.h
%{_includedir}/gelf.h
%{_includedir}/nlist.h
%dir %{_includedir}/elfutils
%{_includedir}/elfutils/*.h
%{_libdir}/libdebuginfod.so
%{_libdir}/libelf.so
%{_libdir}/libdw.so
%{_libdir}/libasm.so
%{_libdir}/pkgconfig/libdebuginfod.pc
%{_libdir}/pkgconfig/libdw.pc
%{_libdir}/pkgconfig/libelf.pc

%files -n %{libnamestaticdevel}
%{_libdir}/*.a


%changelog
* Fri Mar 28 2025 ns80 <ns80> 0.189-1.1.mga9
+ Revision: 2170625
- port patches from Ubuntu for CVE-2024-25260, CVE-2025-1365, CVE-2025-137[27] (mga#34134)

* Tue Mar 14 2023 luigiwalser <luigiwalser> 0.189-1.mga9
+ Revision: 1948858
- 0.189
- remove upstream patches

* Sat Feb 25 2023 daviddavid <daviddavid> 0.188-2.mga9
+ Revision: 1945423
- add upstream patches to fix build with curl >= 7.85.0

* Sun Feb 12 2023 mrambo3501 <mrambo3501> 0.188-1.mga9
+ Revision: 1941011
- version 0.188
- delete upstreamed patches

* Sat May 07 2022 luigiwalser <luigiwalser> 0.187-1.mga9
+ Revision: 1856669
- 0.187
- add upstream patches via fedora

* Fri Mar 25 2022 umeabot <umeabot> 0.186-2.mga9
+ Revision: 1825990
- Mageia 9 Mass Rebuild

* Fri Nov 26 2021 luigiwalser <luigiwalser> 0.186-1.mga9
+ Revision: 1759335
- 0.186

* Sat Oct 02 2021 tmb <tmb> 0.185-3.mga9
+ Revision: 1747340
- rebuild for glibc 2.34

* Thu Aug 05 2021 luigiwalser <luigiwalser> 0.185-2.mga9
+ Revision: 1739392
- do not fail on test suite (will be fixed in 0.186)
- 0.185

* Thu Mar 11 2021 daviddavid <daviddavid> 0.183-1.mga9
+ Revision: 1701418
- new version: 0.183

* Tue Nov 03 2020 luigiwalser <luigiwalser> 0.182-1.mga8
+ Revision: 1642288
- 0.182

* Tue Sep 22 2020 luigiwalser <luigiwalser> 0.181-1.mga8
+ Revision: 1629464
- 0.181
- remove upstream patch 100
- add patch from fedora to add zstd support

* Sun Jul 26 2020 daviddavid <daviddavid> 0.180-2.mga8
+ Revision: 1609149
- add upstream patch to adapt debuginfod to API change in libmicrohttpd-0.9.71

* Thu Jun 25 2020 shlomif <shlomif> 0.180-1.mga8
+ Revision: 1599268
- New version 0.180

* Tue Mar 31 2020 shlomif <shlomif> 0.179-1.mga8
+ Revision: 1562776
- New version 0.179

* Tue Mar 03 2020 tv <tv> 0.178-2.mga8
+ Revision: 1553416
- fix build by not passing --host=foobar
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Dec 08 2019 shlomif <shlomif> 0.178-1.mga8
+ Revision: 1465098
- add BRs
- New version 0.178

* Fri Sep 06 2019 shlomif <shlomif> 0.177-1.mga8
+ Revision: 1437948
- New version 0.177

* Fri Mar 15 2019 shlomif <shlomif> 0.176-1.mga7
+ Revision: 1377672
- New version 0.176

* Thu Feb 07 2019 tmb <tmb> 0.175-2.mga7
+ Revision: 1363867
- rebuild with new binutils

* Wed Nov 28 2018 shlomif <shlomif> 0.175-1.mga7
+ Revision: 1336542
- New version 0.175

* Sun Sep 23 2018 umeabot <umeabot> 0.173-2.mga7
+ Revision: 1297584
- Mageia 7 Mass Rebuild

* Sat Jul 07 2018 shlomif <shlomif> 0.173-1.mga7
+ Revision: 1242551
- New version 0.173

* Fri Jun 22 2018 shlomif <shlomif> 0.172-1.mga7
+ Revision: 1238815
- New version 0.172

* Sat Jun 09 2018 shlomif <shlomif> 0.171-1.mga7
+ Revision: 1235699
- New version 0.171

* Thu Sep 21 2017 akien <akien> 0.170-1.mga7
+ Revision: 1156561
- Version 0.170
- Add P0 to workaround failing test-strip-nothing.sh
- Remove (visibly) unnecessary hacks to Makefile and _disable_ld_no_undefined

* Mon Jul 31 2017 tv <tv> 0.169-2.mga7
+ Revision: 1133077
- move some libs in lib pkg so that biarch works regarding lib{,64}gstreamer1.0_0
- make libs executable so that we generate provides
- make all test executables, thus fixing some failures
- drop MIPS/Sparc patches (unsupported arches)

* Tue May 09 2017 luigiwalser <luigiwalser> 0.169-1.mga6
+ Revision: 1099878
- 0.169
- remove upstreamed security patches

* Tue May 02 2017 neoclust <neoclust> 0.168-2.mga6
+ Revision: 1098701
- Add Patches100-106 - Fixes CVE-2017-760[7-9], CVE-2017-761[0-3] (mga#20557)

* Sun Jan 01 2017 luigiwalser <luigiwalser> 0.168-1.mga6
+ Revision: 1078951
- 0.168
- update URLs

* Mon Oct 10 2016 akien <akien> 0.167-2.mga6
+ Revision: 1060007
- Add upstream patch from Mark Wielaard (rhbz#1380961)

* Wed Sep 07 2016 luigiwalser <luigiwalser> 0.167-1.mga6
+ Revision: 1050395
- 0.167
- rediff patch 10

* Fri Apr 15 2016 shlomif <shlomif> 0.166-1.mga6
+ Revision: 1002758
- New version 0.166

* Mon Jan 25 2016 luigiwalser <luigiwalser> 0.165-1.mga6
+ Revision: 927210
- rediff patch 10
- 0.165

* Tue Nov 17 2015 blino <blino> 0.164-1.mga6
+ Revision: 903727
- remove unapplied skip_elflint_self_test patch
- drop old gcc compat and check conditionals (like Fedora)
- 0.164
- fix mips backend to remove old-style function definitions
  (see upstream commits aa1c2ca808a267a5a3c372de5461c1f67f9a8869
   and 1ccdfb683ad6c7e59793136c3a657ddf131cafd1)

* Mon Sep 14 2015 blino <blino> 0.163-1.mga6
+ Revision: 879050
- 0.163
- drop dir traversal patch (merged upstream)
- sync portability patch with upstream
- rediff MIPS patch

* Fri Aug 21 2015 tmb <tmb> 0.160-5.mga6
+ Revision: 867564
- rebuild for new gcc

* Tue Dec 30 2014 luigiwalser <luigiwalser> 0.160-4.mga5
+ Revision: 807228
- add upstream patch to fix ar extraction being able to overwrite
  files in root (CVE-2014-9447)

* Wed Oct 15 2014 umeabot <umeabot> 0.160-3.mga5
+ Revision: 743683
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.160-2.mga5
+ Revision: 678987
- Mageia 5 Mass Rebuild

* Sun Aug 31 2014 luigiwalser <luigiwalser> 0.160-1.mga5
+ Revision: 670039
- update patch 10 (mips_backend) for elfutils-0.160
- 0.160
- update portability patch

* Fri May 23 2014 luigiwalser <luigiwalser> 0.159-1.mga5
+ Revision: 625178
- 0.159
- update description (from fedora)
- remove upstreamed patches (CVE-2014-0172, mod-e_type, robustify)
- update portability patch

* Wed Apr 09 2014 luigiwalser <luigiwalser> 0.158-1.mga5
+ Revision: 613059
- 0.158
- rediff patch 10 (mips backend)
- update portability and robustify patches
- remove patch 13 (signed comparison) fixed upstream
- add mod-e_type patch from fedora
- add upstream patch to fix CVE-2014-0172

* Tue Oct 22 2013 umeabot <umeabot> 0.157-3.mga4
+ Revision: 545647
- Mageia 4 Mass Rebuild

* Wed Oct 16 2013 tmb <tmb> 0.157-2.mga4
+ Revision: 501531
- rebuild for new gcc & binutils

* Thu Oct 10 2013 luigiwalser <luigiwalser> 0.157-1.mga4
+ Revision: 494927
- 0.157
- remove upstreamed patches 3 (binutils) and 15 (automake 1.13)
- enable parallel make for make check (necessary fixes made upstream)
- rediff patches 10 (mips backend) and 13 (signed comparison)
- update portability and robustify patches

* Sun Jan 13 2013 cjw <cjw> 0.155-2.mga3
+ Revision: 380039
- patch15: fix tests with automake 1.13
- don't use parallel make for the tests
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 13 2012 rtp <rtp> 0.155-1.mga3
+ Revision: 330093
- update to 0.155
- refresh mips, robustify, portability patches
- update patch for ld/13621
- drop old patches
- don't apply patch making always succeed elflint patch as it conflicts with
  patch for ld/13621

* Tue Aug 28 2012 tv <tv> 0.154-3.mga3
+ Revision: 284670
+ rebuild (emptylog)

* Tue Aug 28 2012 tv <tv> 0.154-2.mga3
+ Revision: 284669
- resync & reeanble robustify/portability patches from FC
- add patches from FC for dwz support

* Wed Jun 27 2012 tv <tv> 0.154-1.mga3
+ Revision: 264240
- new release

* Sun Jun 03 2012 tv <tv> 0.153-1.mga3
+ Revision: 253626
- new release

* Sat Apr 16 2011 pterjan <pterjan> 0.152-1.mga1
+ Revision: 86612
- Update to 0.152
- Fix Source URL
+ rtp <rtp>
- rediff mips_backend patch (back to a "normal" 40-50k size instead of 600k)
- fix some signed vs unsigned comparisons (appears only on some arches)
- run elflint test but don't make it fail on arm/mips.

* Sat Jan 08 2011 blino <blino> 0.150-1.mga1
+ Revision: 1135
- remove old distro stuff
- imported package elfutils


* Sat Nov 27 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.150-1mdv2011.0
+ Revision: 601940
- update to new version 0.150

* Sat Nov 27 2010 Funda Wang <fwang@mandriva.org> 0.149-2mdv2011.0
+ Revision: 601638
- rebuild for py liblzma

* Thu Sep 16 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.149-1mdv2011.0
+ Revision: 579048
- update to new version 0.149

* Sun Jul 11 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.148-1mdv2011.0
+ Revision: 551017
- update to new version 0.148

* Wed Apr 28 2010 Emmanuel Andry <eandry@mandriva.org> 0.146-1mdv2010.1
+ Revision: 540498
- New version 0.146
- update p0 and p1
- BR gettext-devel
- update files list

* Sat Apr 03 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.145-1mdv2010.1
+ Revision: 530871
- update to new version 0.145
- rediff patch 10

* Mon Feb 01 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 0.144-1mdv2010.1
+ Revision: 499243
- update to new version 0.144

* Wed Sep 23 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.143-1mdv2010.0
+ Revision: 448079
- enable support for lzma
- update to new version 0.143
- update robustify and portability patches

* Sat Aug 01 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.142-1mdv2010.0
+ Revision: 407145
- update portability and robustify patches
- adapt mips patch to the latest elfutils changes
- update to new version 0.142

* Sat May 02 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.141-1mdv2010.0
+ Revision: 370677
- update to new version 0.141

* Fri Feb 20 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.140-1mdv2009.1
+ Revision: 343294
- update patch 0 and 1

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - new release: 0.140
    - add back sparc patches which were previously dropped due to laziness by others:/
    - add mips backend (P10 from 2008.1 Gdium tree)

* Sat Jan 24 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.139-1mdv2009.1
+ Revision: 333340
- enable thread safety (TLS)
- add buildrequires on zlib-devel and bzip2-devel, since libdwfl can auto-decompress ELF files
- Patch 0 and 1: update to 0.139
- drop patch2, merged upstream
- update to new version 0.139

* Sat Jan 03 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0.138-1mdv2009.1
+ Revision: 323566
- Patch1: new version
- Patch2: fix regression introduced in elfutils-0.138
- better description
- update to new version 0.138

* Mon Dec 29 2008 Oden Eriksson <oeriksson@mandriva.com> 0.137-2mdv2009.1
+ Revision: 321096
- rebuild

* Wed Sep 03 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.137-1mdv2009.0
+ Revision: 279399
- Patch 0 and 1: new versions
- obsolete older versions than 0.137
- run autoreconf, needed by portability patch
- drop additional tests, sources 2 and 3
- update to new version 0.137
- add sig file
- reorder sources

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 0.135-2mdv2009.0
+ Revision: 264438
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
    - set %%_disable_ld_no_undefined (needed by libld_elf_i386.so) instead of messing LDFLAGS

* Sun May 25 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.135-1mdv2009.0
+ Revision: 211246
- update to new version 0.135
- drop all patches excluding patch 0 and 1
- re-define LDFLAGS
- package libasm
- package eu-objdump program
- fix file list

* Sun Feb 10 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 0.131-2mdv2008.1
+ Revision: 164990
- rebuild

* Sun Dec 30 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.131-1mdv2008.1
+ Revision: 139413
- add two test files (Source 1 and 2)
- provide updated version of patch 6  (gnu_inline)
- fix mem leak with patch 9
- provide patches 10 and 11 (minor upstream fixes)
- patch 8 has been merged upstream
- drop useles buildrequires on sharutils and libtool-devel (?)
- add buildrequires on bison and flex
- new program: eu-make-debug-archive
- spec file clean
- correct Source0
- new version 0.131
- update upstream patches 0,1,2

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sat Jul 14 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 0.128-1mdv2008.0
+ Revision: 52067
- new program: eu-strip
- remove dead entries in spec file
- correct libification
- correct patch order
- provide patch 6 (gnu_inline)
- provide patches 7 and 8 (minor fixes)
- new version 0.128

* Thu Jun 21 2007 Olivier Thauvin <nanardon@mandriva.org> 2mdv2008.0-current
+ Revision: 42294
- don't redefine _gnu to nil
- apply new devel policy

* Fri Jun 08 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 0.127-1mdv2008.0
+ Revision: 37513
- Updated to version 0.127.
- Added updated upstream versions of patches portability and robustify
  (fedora).

* Thu May 03 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.126-1mdv2008.0
+ Revision: 20819
- new release: 0.126
- sync patches with fedora


* Sat Jan 27 2007 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.125-2mdv2007.0
+ Revision: 114272
- elfutils should now work on sparc! :)
- support special case of SPARC ELF32 PLT entires (P6 from PLD)
- allocated pointers need 8-byte alignment on sparc (to use ldd/std opcodes to access 8-byte aligned structs) (P5 from PLD)

* Thu Jan 25 2007 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.125-1mdv2007.1
+ Revision: 113565
- check fails on other archs than sparc too, enable it for all but make failure non-fatal
- reenable check (except for sparc)
- new release: 0.125
- Fix overeager warn_unused_result build failures. (P3 from fedora)
- eu-strip -f: copy symtab into debuginfo file when relocs use it (P4 from fedora, RHBZ #203000)

* Tue Oct 31 2006 Oden Eriksson <oeriksson@mandriva.com> 0.120-3mdv2007.1
+ Revision: 74664
- bunzip patches
- Import elfutils

* Mon May 15 2006 Stefan van der Eijk <stefan@eijk.nu> 0.120-2mdk
- rebuild for sparc

* Wed Apr 19 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.120-1mdk
- 0.120
- update robustification patch (P1)
- fix sparc build (P2)
- License has been changed to GPL, except for libraries which is still OSL
- move check to %%check stage
- disable checks on sparc

* Thu Apr 06 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.119-2mdk
- add robustification patch (P1) from fedora
- don't give errors on compile warnings on sparc

* Fri Jan 27 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.119-1mdk
- 0.119
- %%mkrel

* Wed Dec 28 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.118-1mdk
- 0.118

* Wed Jul 27 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 0.109-1mdk
- 0.109

* Thu Feb 17 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.99-1mdk
- 0.99

* Sun Jan 23 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 0.97-1mdk
- 0.97
- fix summary-ended-with-dot

* Sat Sep 18 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.96-1mdk
- 0.96

